@@ -3,7 +3,7 @@ from abc import ABC, abstractmethod
 from datetime import datetime
 from enum import Enum
 from minty.object import Field, IntrospectableObject
-from typing import List
+from typing import Iterable, List
 from uuid import UUID
 
 
@@ -253,3 +253,13 @@ class Entity(IntrospectableObject):
             )
 
         return wrapper
+
+
+class EntityCollection:
+    """Multiple entities."""
+
+    def __init__(self, entities: Iterable[Entity]):
+        self.entities = entities
+
+    def __iter__(self):
+        return iter(self.entities)
